#!/bin/sh
#	Reduces data by first tokenising it and then concatenating.
#
#	Copyright Les Hatton, 2013-.
#	Released under the GNU GPL.
#
#	Revision:	$Revision: 1.4 $
#	Date:	$Date: 2017/11/11 17:00:27 $
#-----------------------------------------
TOPDIR=.

if test ! -f uniprot_trembl.fasta.gz
then
	echo "Protein data ............................................."
	echo "You have not downloaded the compressed data uniprot_trembl.fasta.gz"
	echo "Checking to see if the processed form is available ..."

	if test ! -f trembl_lengths.raw.gz
	then
		echo "... no processed data available.  See 1-downloadDataSets.sh."
		exit
	else
		echo "The processed form trembl_lengths.raw is available.  This will be used."
	fi
else
	echo "The uniprot_trembl.fasta raw protein dataset is available."
	echo "Checking to see if the processed form is present and if not"
	echo "it will be created."

	if test ! -f trembl_lengths.raw.gz
	then
		echo "Creating the raw pairs dataset trembl_lengths.raw"
		echo "This will take a while ........................"
		zcat uniprot_trembl.fasta.gz | ./fastaToTok.pl > trembl_lengths.raw
		gzip	trembl_lengths.raw
	fi
fi

echo "Preparation of processed protein datasets completed:-"
ls -l trembl_lengths.raw.gz
echo

echo "Software data ............................................"
echo "For full reproducibility, you will have to download a lot of open source"
echo "... http://www.leshatton.org/Documents/Data_TSE-2013-08-0271_V1.0a.zip"
echo "This however should not be necessary and you can continue here"
echo "as the dataset used in the paper is included as c_ti.raw.gz"
if test ! -f c_ti.raw.gz
then
	echo	"The raw C data set c_ti.raw.gz is missing"
	exit
fi

echo "Music data ............................................"
if test ! -f musicxml.zip
then
	echo	"The raw C data set musicxml.zip is missing"
	exit
fi
#
#	We need to unzip this as we can't do it on the fly.
#
unzip musicxml.zip
#
#	Finally, we will need the normaliser.
#
if test ! -f normalise
then
	cc -o normalise normalise.c
fi

echo "You may now continue with the processing stages, 3-xxxx.sh for each figure"
echo "shown in the Main Paper."
