#!/usr/bin/perl
#
#	Calculate the homogeneous case using the Ramanujan approximation.
#	We are studying the droopy tail.
#
#	Revision:	$Revision: 1.1 $
#	Date:	$Date: 2018/11/19 16:57:02 $
#--------------------------------------------------------------
#
use 	strict;
use 	warnings;
use	Getopt::Long;

my	$ALPHA	= -0.001;
my	$BETA	= 3.0;
my	$TIMIN	= 1;
my	$TIMAX	= 20000;
my	$MODE	= "ramanujan";
my	$scale	= 5000.0;

GetOptions(
	'alpha=f'		=> \$ALPHA,
	'beta=f'		=> \$BETA,
	'mode=s'		=> \$MODE,
);
#---------------------------------------------------
#	General purpose integer factorial function.
#	Computed factor by factor to delay onset of overflow.
#
sub	factorial()
{
	my	($n)		= @_;

	my	$result	= 1;
	for( my $i = 2; $i <= $n; ++$i )
	{
		$result	*= $i;
	}

	return	$result;
}
#---------------------------------------------------
#	General purpose integer log factorial function.
#	Computed factor by factor to delay onset of overflow.
#
sub	logfactorial()
{
	my	($n)		= @_;

	my	$result	= 0.0;
	for( my $i = 2; $i <= $n; ++$i )
	{
		$result	+= log($i);
	}

	return	$result;
}
#---------------------------------------------------
#	Calcualte offset from exact so it matches with Stirling.
#
	my	$EXACT	= 200;
#
#	Initially just look for rank solutions.
#
for( my $ti = $TIMIN; $ti <= $TIMAX; ++$ti )
{
#
#	Incorporates Ramanujan's approximation for log n!.
#	https://en.wikipedia.org/wiki/Stirling%27s_approximation
#	Ramanujan's approximation is:-
#
#		log n! \approx n log n - n + 1/6 log(n + 4n^2 + 8n^3) + 1/2log(\pi)
#
	my	$srinivasa	= 0.0;
	my	$factor		= 0.0;

	if ( $MODE eq "ramanujan" )
	{
		$factor	= $ti*log($ti) - $ti +  (1.0 / (6.0*log($ti + 4*$ti*$ti + 8*$ti*$ti*$ti))) + 0.5*log(3.14159265);
	}
	elsif ( $MODE eq "stirling" )
	{
		$factor	= $ti*log($ti) - $ti;
	}
	elsif ( $MODE eq "exact" )
	{
		$factor	= $ti*log($ti) - $ti;
#
#		As $ti gets small, calculate it exactly.
#
		if ( $ti < $EXACT )
		{
			$factor	= &logfactorial($ti);
		}
	}
	else
	{
		die "-mode must be ramanujan, stirling or exact";
	}
#
#	The integrated CoHSI homogeneous equation is:-
#
#		-($ti log($ti) - $ti + $srinivasa - $ti*$ALPHA)/($ti*$BETA) = log rank
#
#	Here, N() is the chocolate box function and log N() is its HS information.
#
#	For the homogeneous case N() = ti log r, where r is the rank.
#
#	my	$lhscohsi		= -($factor - $ti*$ALPHA)/($ti*$BETA);
	my	$lhscohsi		= -(($factor/$ti) + ($ALPHA-1.0))/($BETA);
	my	$rank		= exp($lhscohsi);

	printf "%f %f\n", $scale*$rank, $ti;
}

exit(0);
